# -*- coding: utf-8 -*-
# This enhancement will create a future alert by directly uploading documents to ES.

import datetime
from elastalert.enhancements import BaseEnhancement
from elastalert.enhancements import DropMatchException
from elastalert.elastalert import ElastAlerter
from elastalert.util import ts_to_dt, ts_now


class FutureAlertEnhancement(BaseEnhancement):
    def __init__(self, *args):
        super(FutureAlertEnhancement, self).__init__(*args)
        self.alert_time_delta = datetime.timedelta(**self.rule.get('alert_time_delta'))
        self.pending_alerts = {}
        es_conf = ElastAlerter.build_es_conn_config(self.rule)
        self.es = ElastAlerter.new_elasticsearch(es_conf)

    def process(self, match):
        # This process command will run 3 times:
        # 1. When the event type 1 occurs, it will add "pending_alert" to the match and upload it
        # 2. When event type 2 occurs, it will try to delete the pending alert
        # 3. When the pending alert finally fires. At this point, we do nothing

        # This could also be implemented as two separate rules, using querying instead of self.pending_alerts
        # That would also make it safe if the service got restarted while an alert was pending

        if 'pending_alert' not in match:
            # Skips #3 

            if 1: # This should be "If match is event type 1 (Adds a pending alert)".
                match['pending_alert'] = True
                # Copied from ElastAlerter.get_alert_body
                body = {'match_body': match,
                        'rule_name': self.rule['name'],
                        'alert_info': {'type': 'deferred'},
                        'alert_sent': False,
                        'alert_time': ts_to_dt(ts_now()) + self.alert_time_delta, # This uses the present time, not time of the match
                        '@timestamp': ts_now()}
                res = self.es.create(index='elastalert_status', doc_type='elastalert', body=body) 
                _id = res['_id']
                # This needs to use something from the match to map pending alerts
                self.pending_alerts[match.get('something', 'default')] = _id
                raise DropMatchException

            else: # Event type 2.
                key = match.get('something', 'default')
                if key in self.pending_alerts:
                    self.es.delete(index='elastalert_status', doc_type='elastalert', id=self.pending_alerts[key])
                raise DropMatchException


