# -*- coding: utf-8 -*-
import datetime

from elastalert.ruletypes import RuleType
from elastalert.util import lookup_es_key


class SeagullArtifactDownloadRule(RuleType):
    """This is an elastAlert rule specific for seagull.
    Alert team releng when average artifact downdown time exceeds threshold
    """
    required_options = frozenset(['field', 'threshold'])

    def add_data(self, data):
        slaves = {}
        total = 0.0
        for document in data:
            total += lookup_es_key(document, self.rules['field'])
            hostname = lookup_es_key(document, 'payload.hostname')
            if hostname is None:
                continue

            if hostname in slaves:
                slaves[hostname]['downloads'].append(lookup_es_key(document, self.rules['field']))
            else:
                slaves[hostname] = {'downloads': [lookup_es_key(document, self.rules['field'])], 'hostname': hostname}

        average = total / len(data)
        for hostname, metrics in slaves.iteritems():
            metrics['average'] = sum(metrics['downloads']) / len(metrics['downloads'])

        if average > self.rules['threshold']:
            self.add_match({
                'average': average,
                '@timestamp': datetime.datetime.now().isoformat(),
                'slaves': sorted(slaves.values(), key=lambda metric: metric['average'], reverse=True)
            })

    def get_match_str(self, match):
        msg = "Average seagull artifact download time %f is larger than threshold %f.\n\n" % (match['average'], self.rules['threshold'])
        msg += "\n".join(["average download time on host: %s is %f" % (host['hostname'], host['average']) for host in match['slaves']])
        return msg
