# -*- coding: utf-8 -*-
import commands

from elastalert.alerts import Alerter, BasicMatchString
from elastalert.util import EAException


class NodebotAlerter(Alerter):
    """ Uses the local nodebot client to send alerts to IRC.
        Useful for informational stuff that doesn't require
        a stateful alert """
    required_options = frozenset(['nodebot'])

    def __init__(self, rule):
        super(NodebotAlerter, self).__init__(rule)
        if 'irc-channel' not in rule['nodebot']:
            raise EAException('Nodebot configuration must include at least irc-channel')

    def alert(self, matches):
        channel = self.rule['nodebot'].get('irc-channel')

        description = ''
        for match in matches:
            # cram everything into a single line for IRC fun
            description += str(BasicMatchString(self.rule, match)).replace("\n", " ")

        (status, output) = commands.getstatusoutput("/nail/sys/bin/nodebot %s \"%s\"" % (channel, description))
        if status != 0:
            raise EAException('Sending message to IRC failed with message: %s' % output)

    def get_info(self):
        return {'type': 'nodebot'}
