# -*- coding: utf-8 -*-
import datetime

from elastalert.ruletypes import RuleType
from elastalert.util import lookup_es_key


class SeagullLostTestsRule(RuleType):
    """This is an elastalert rule specific for seagull.
    Alert us when every seagull-run has more than a certain amount of lost tests.
    We do not care a particular use has lots of lost tests.
    """
    required_options = frozenset(['threshold'])

    def add_data(self, data):
        users = {}
        for document in data:
            unique_parent_id = lookup_es_key(document, 'payload.unique_parent_id')
            users[unique_parent_id] = users.get(unique_parent_id, 0) + 1

        if len(users) > 1:
            for user, lost_test in users.iteritems():
                if lost_test < self.rules['threshold']:
                    return

            self.add_match({
                '@timestamp': datetime.datetime.now().isoformat(),
                'lost_tests': users
            })

    def get_match_str(self, match):
        msg = "Every seagull-run has more than %d lost tests\n\n" % (self.rules['threshold'])
        msg += "\n".join(["%s has %d lost tests" % (user, lost_tests) for user, lost_tests in match['lost_tests'].iteritems()])
        return msg
