# -*- coding: utf-8 -*-
import re

import pysensu_yelp

from elastalert.alerts import Alerter, BasicMatchString
from elastalert.util import EAException


class SensuAlerter(Alerter):
    """ Uses the local Sensu client through pysensu-yelp for alerts. """
    required_options = frozenset(['sensu'])

    def __init__(self, rule):
        super(SensuAlerter, self).__init__(rule)
        rule['sensu'].setdefault('runbook', 'y/unknown')
        rule['sensu'].setdefault('status', 1)
        if 'team' not in rule['sensu']:
            raise EAException('Sensu configuration must include at least team')

    def alert(self, matches):
        # Remove special characters from the name
        name = self.rule['sensu'].get('name')
        if not name:
            name = re.sub('[^\w\.-]', '', self.rule['name'].replace(' ', '_'))

        description = ''
        for match in matches:
            description += str(BasicMatchString(self.rule, match))
            if len(matches) > 1:
                description += '\n----------------------------------------\n'

        pysensu_yelp.send_event(name, output=description, **self.rule['sensu'])

    def get_info(self):
        return {'type': 'sensu'}
