# -*- coding: utf-8 -*-
import logging
import yaml
import checkout_fulfillment.stub as cf_mod
from elastalert.alerts import EmailAlerter
from elastalert.util import EAException
from yelp_lib.decorators import retry

# SEC-3310. ElastAlert doesn't play well with staticconf, so hardcode the services.yaml path
try:
    with open('/nail/srv/configs/services.yaml') as services_file:
        services = yaml.load(services_file.read())
        cf_host = services['services']['checkout_fulfillment']['hostname']
        cf_port = services['services']['checkout_fulfillment']['port']
    cf_mod.hostname = cf_host
    cf_mod.port = cf_port
except Exception as e:
    logging.exception("Couldn't read checkout_fulfillment service config: %s" % (e))


class PartnerEmailer(EmailAlerter):
    """This module derives the email address to which alert should be send.
    priorities in descending order is email_from_static_map, email_from_rule,
    email_from_cf else default_email.
    """
    required_options = EmailAlerter.required_options \
        .union(['recipients_map', 'recipient_key']) \
        .difference(['email'])
    default_email = ['platform-notifications@yelp.com']
    email_from_rule = None

    def __init__(self, *args, **kwargs):
        super(EmailAlerter, self).__init__(*args, **kwargs)
        assert self.default_email
        if 'email' in self.rule:
            self.email_from_rule = self.rule['email']
        else:
            self.rule['email'] = self.default_email
        super(PartnerEmailer, self).__init__(*args, **kwargs)

    def alert(self, matches):
        if len(matches) != 1:
            raise EAException('PartnerEmailer expecting exactly one match. Received %d matches' % len(matches))
        key = matches[0].get(self.rule['recipient_key'])
        email_from_static_map = self.rule['recipients_map'].get(key)
        email_from_cf = None
        if not (email_from_static_map or self.email_from_rule) and matches[0].get('partner_id'):
            try:
                email_from_cf = self._get_partner_email_from_cf(matches[0].get('partner_id'))
            except Exception as e:
                logging.critical(
                    'PartnerEmailer could not retrive email for partner_id %s from CF, '
                    'exception_msg %s' % (matches[0].get('partner_id'), str(e))
                )
        email = email_from_static_map or self.email_from_rule or email_from_cf or self.default_email
        self.rule['email'] = email if isinstance(email, list) else [email]
        import pdb;pdb.set_trace()
        super(PartnerEmailer, self).alert(matches)

    @retry(tries=3, delay=1)
    def _get_partner_email_from_cf(self, partner_id):
        cf_stub = cf_mod.CheckoutFulfillmentStub()
        partner_contract_list = cf_stub.list_partner_contracts(
            partner_id=int(partner_id)
        )().get('partner_contracts')
        if partner_contract_list and len(partner_contract_list) > 0:
            return partner_contract_list[0]['notify_email']
        else:
            return None
