# -*- coding: utf-8 -*-
import dateutil.tz
from elastalert.ruletypes import FlatlineRule


class YtpTimeWindowFlatlineRule(FlatlineRule):
    """This is an elastalert rule which applies the flatline logic only within a
    specific time-of-day window.
    """
    required_options = frozenset(['timeframe', 'threshold', 'start_time', 'end_time'])

    def __init__(self, *args):
        super(YtpTimeWindowFlatlineRule, self).__init__(*args)
        self.start_time = self.rules['start_time']
        self.end_time = self.rules['end_time']

    def check_for_match(self, key):
        """ Mostly the same as the superclass, but with window-checking logic """
        most_recent_ts = self.get_ts(self.occurrences[key].data[-1])
        if self._in_window(most_recent_ts):
            super(YtpTimeWindowFlatlineRule, self).check_for_match(key)

    def _in_window(self, dt):
        time = dt.astimezone(dateutil.tz.tzlocal()).time()
        time_comparable = time.hour * 100 + time.minute
        if self.start_time < self.end_time:  # normal case, if both start and ent time are in the same day
            return time_comparable >= self.start_time and time_comparable < self.end_time
        else:  # complicated case, we are doing something like 8pm->8am
            return (time_comparable < self.end_time) or (time_comparable >= self.start_time)
